[Libreoffice-commits] core.git: chart2/source drawinglayer/source include/svx sc/source svx/source sw/source test/source toolkit/test vcl/opengl vcl/source

Andras Timar andras.timar at collabora.com
Tue May 5 00:25:45 PDT 2015


 chart2/source/view/axes/Tickmarks.cxx                     |   10 +++++-----
 chart2/source/view/axes/Tickmarks.hxx                     |    2 +-
 drawinglayer/source/attribute/sdrfillgraphicattribute.cxx |    2 +-
 include/svx/svdsnpv.hxx                                   |    2 +-
 sc/source/filter/excel/xichart.cxx                        |    4 ++--
 sc/source/filter/lotus/lotimpop.cxx                       |    2 +-
 svx/source/sdr/primitive2d/sdrdecompositiontools.cxx      |    2 +-
 svx/source/unodraw/unobrushitemhelper.cxx                 |    2 +-
 sw/source/core/crsr/crstrvl.cxx                           |    2 +-
 sw/source/core/layout/ftnfrm.cxx                          |    2 +-
 test/source/mtfxmldump.cxx                                |    2 +-
 toolkit/test/accessibility/ov/ObjectViewContainer.java    |    2 +-
 vcl/opengl/win/WinDeviceInfo.cxx                          |    2 +-
 vcl/source/filter/sgvtext.cxx                             |    6 +++---
 14 files changed, 21 insertions(+), 21 deletions(-)

New commits:
commit f62af191bf0f0d1578abc919ca3c902864fefa22
Author: Andras Timar <andras.timar at collabora.com>
Date:   Mon May 4 18:12:42 2015 +0200

    typo: strech -> stretch
    
    Change-Id: I0de1cfaa0df460c7bc8e49752b31056f95c30053
    Reviewed-on: https://gerrit.libreoffice.org/15628
    Reviewed-by: Andras Timar <andras.timar at collabora.com>
    Tested-by: Andras Timar <andras.timar at collabora.com>

diff --git a/chart2/source/view/axes/Tickmarks.cxx b/chart2/source/view/axes/Tickmarks.cxx
index a8cd9a5..6f12154 100644
--- a/chart2/source/view/axes/Tickmarks.cxx
+++ b/chart2/source/view/axes/Tickmarks.cxx
@@ -139,20 +139,20 @@ void TickFactory::updateScreenValues( TickInfoArraysType& /*rAllTickInfos*/ ) co
 // ___TickFactory_2D___
 TickFactory2D::TickFactory2D(
           const ExplicitScaleData& rScale, const ExplicitIncrementData& rIncrement
-          //, double fStrech_SceneToScreen, double fOffset_SceneToScreen )
+          //, double fStretch_SceneToScreen, double fOffset_SceneToScreen )
           , const B2DVector& rStartScreenPos, const B2DVector& rEndScreenPos
           , const B2DVector& rAxisLineToLabelLineShift )
           : TickFactory( rScale, rIncrement )
           , m_aAxisStartScreenPosition2D(rStartScreenPos)
           , m_aAxisEndScreenPosition2D(rEndScreenPos)
           , m_aAxisLineToLabelLineShift(rAxisLineToLabelLineShift)
-          , m_fStrech_LogicToScreen(1.0)
+          , m_fStretch_LogicToScreen(1.0)
           , m_fOffset_LogicToScreen(0.0)
 {
     double fWidthY = m_fScaledVisibleMax - m_fScaledVisibleMin;
     if (chart2::AxisOrientation_MATHEMATICAL == m_rScale.Orientation)
     {
-        m_fStrech_LogicToScreen = 1.0/fWidthY;
+        m_fStretch_LogicToScreen = 1.0/fWidthY;
         m_fOffset_LogicToScreen = -m_fScaledVisibleMin;
     }
     else
@@ -161,7 +161,7 @@ TickFactory2D::TickFactory2D(
         m_aAxisStartScreenPosition2D = m_aAxisEndScreenPosition2D;
         m_aAxisEndScreenPosition2D = aSwap;
 
-        m_fStrech_LogicToScreen = -1.0/fWidthY;
+        m_fStretch_LogicToScreen = -1.0/fWidthY;
         m_fOffset_LogicToScreen = -m_fScaledVisibleMax;
     }
 }
@@ -197,7 +197,7 @@ B2DVector TickFactory2D::getTickScreenPosition2D( double fScaledLogicTickValue )
 {
     B2DVector aRet(m_aAxisStartScreenPosition2D);
     aRet += (m_aAxisEndScreenPosition2D-m_aAxisStartScreenPosition2D)
-                *((fScaledLogicTickValue+m_fOffset_LogicToScreen)*m_fStrech_LogicToScreen);
+                *((fScaledLogicTickValue+m_fOffset_LogicToScreen)*m_fStretch_LogicToScreen);
     return aRet;
 }
 
diff --git a/chart2/source/view/axes/Tickmarks.hxx b/chart2/source/view/axes/Tickmarks.hxx
index b47dde2b..b9ecc35 100644
--- a/chart2/source/view/axes/Tickmarks.hxx
+++ b/chart2/source/view/axes/Tickmarks.hxx
@@ -150,7 +150,7 @@ private: //member
     //add this vector to go from the axis line to the label line (border of the diagram)
     ::basegfx::B2DVector    m_aAxisLineToLabelLineShift;
 
-    double      m_fStrech_LogicToScreen;
+    double      m_fStretch_LogicToScreen;
     double      m_fOffset_LogicToScreen;
 };
 
diff --git a/drawinglayer/source/attribute/sdrfillgraphicattribute.cxx b/drawinglayer/source/attribute/sdrfillgraphicattribute.cxx
index 2e7f05e..4ad7cdb 100644
--- a/drawinglayer/source/attribute/sdrfillgraphicattribute.cxx
+++ b/drawinglayer/source/attribute/sdrfillgraphicattribute.cxx
@@ -213,7 +213,7 @@ namespace drawinglayer
             basegfx::B2DPoint aBitmapSize(1.0, 1.0);
             basegfx::B2DVector aBitmapTopLeft(0.0, 0.0);
 
-            //UUUU are changes needed? When streched we are already done, all other values will have no influence
+            //UUUU are changes needed? When stretched we are already done, all other values will have no influence
             if(getTiling() || !getStretch())
             {
                 // init values with range sizes
diff --git a/include/svx/svdsnpv.hxx b/include/svx/svdsnpv.hxx
index 8f2eeea..fb2fc32 100644
--- a/include/svx/svdsnpv.hxx
+++ b/include/svx/svdsnpv.hxx
@@ -222,7 +222,7 @@ public:
     //   - object-specific Dragging
     //     - rectangle corner radius: nothing
     //     - circle object angle: nothing
-    //     - line keeps while Dragging the angle and is only streched/ contracted
+    //     - line keeps while Dragging the angle and is only stretched/ contracted
     // Default value for Ortho is off. persistent.
     void SetOrtho(bool bOn) { bOrtho=bOn; } // unvollstaendig
     bool IsOrtho() const { return bOrtho; }
diff --git a/sc/source/filter/excel/xichart.cxx b/sc/source/filter/excel/xichart.cxx
index 077a1c8..b0b3834 100644
--- a/sc/source/filter/excel/xichart.cxx
+++ b/sc/source/filter/excel/xichart.cxx
@@ -1520,9 +1520,9 @@ void XclImpChDataFormat::Convert( ScfPropertySet& rPropSet, const XclChExtTypeIn
     /*  Line and area format.
         #i71810# If the data points are filled with bitmaps, textures, or
         patterns, then only bar charts will use the CHPICFORMAT record to
-        determine stacking/streching mode. All other chart types ignore this
+        determine stacking/stretching mode. All other chart types ignore this
         record and always use the property 'fill-type' from the DFF property
-        set (streched for bitmaps, and stacked for textures and patterns). */
+        set (stretched for bitmaps, and stacked for textures and patterns). */
     bool bUsePicFmt = rTypeInfo.meTypeCateg == EXC_CHTYPECATEG_BAR;
     ConvertFrameBase( GetChRoot(), rPropSet, rTypeInfo.GetSeriesObjectType(), maData.mnFormatIdx, bUsePicFmt );
 
diff --git a/sc/source/filter/lotus/lotimpop.cxx b/sc/source/filter/lotus/lotimpop.cxx
index 0b49b0f..8df563a 100644
--- a/sc/source/filter/lotus/lotimpop.cxx
+++ b/sc/source/filter/lotus/lotimpop.cxx
@@ -313,7 +313,7 @@ void ImportLotus::RowPresentation( sal_uInt16 nRecLen )
         Read( nFlags );
         Skip( 1 );
 
-        if( nFlags & 0x02 )     // Fixed / Strech to fit fonts
+        if( nFlags & 0x02 )     // Fixed / Stretch to fit fonts
         {   // fixed
             // Height in Lotus in 1/32 Points
             nHeight *= 20;  // -> 32 * TWIPS
diff --git a/svx/source/sdr/primitive2d/sdrdecompositiontools.cxx b/svx/source/sdr/primitive2d/sdrdecompositiontools.cxx
index a961f28..ddc6608 100644
--- a/svx/source/sdr/primitive2d/sdrdecompositiontools.cxx
+++ b/svx/source/sdr/primitive2d/sdrdecompositiontools.cxx
@@ -297,7 +297,7 @@ namespace drawinglayer
 
                 if(rText.isFitToSize())
                 {
-                    // streched text in range
+                    // stretched text in range
                     pNew = new SdrStretchTextPrimitive2D(
                         &rText.getSdrText(),
                         rText.getOutlinerParaObject(),
diff --git a/svx/source/unodraw/unobrushitemhelper.cxx b/svx/source/unodraw/unobrushitemhelper.cxx
index d10aab6..42b3d5f 100644
--- a/svx/source/unodraw/unobrushitemhelper.cxx
+++ b/svx/source/unodraw/unobrushitemhelper.cxx
@@ -74,7 +74,7 @@ void setSvxBrushItemAsFillAttributesToTargetSet(const SvxBrushItem& rBrush, SfxI
             rToSet.Put(XFillBmpStretchItem(true));
             rToSet.Put(XFillBmpTileItem(false));
 
-            // default for strech is also top-left, but this will not be visible
+            // default for stretch is also top-left, but this will not be visible
             rToSet.Put(XFillBmpPosItem(RP_LT));
         }
         else if(GPOS_TILED == rBrush.GetGraphicPos())
diff --git a/sw/source/core/crsr/crstrvl.cxx b/sw/source/core/crsr/crstrvl.cxx
index c45e604..b0caa56 100644
--- a/sw/source/core/crsr/crstrvl.cxx
+++ b/sw/source/core/crsr/crstrvl.cxx
@@ -2090,7 +2090,7 @@ const SwRangeRedline* SwCrsrShell::GotoRedline( sal_uInt16 nArrPos, bool bSelect
                 if( pTmp && bCheck )
                 {
                     // Check for overlaps. These can happen when FmtColl-
-                    // Redlines were streched over a whole paragraph
+                    // Redlines were stretched over a whole paragraph
                     SwPaM* pCur = m_pCurCrsr;
                     SwPaM* pNextPam = pCur->GetNext();
                     SwPosition* pCStt = pCur->Start(), *pCEnd = pCur->End();
diff --git a/sw/source/core/layout/ftnfrm.cxx b/sw/source/core/layout/ftnfrm.cxx
index 6a02d28..197290a 100644
--- a/sw/source/core/layout/ftnfrm.cxx
+++ b/sw/source/core/layout/ftnfrm.cxx
@@ -1559,7 +1559,7 @@ void SwFtnBossFrm::AppendFtn( SwCntntFrm *pRef, SwTxtFtn *pAttr )
         ::RegistFlys( pNew->FindPageFrm(), pNew );
         SwSectionFrm* pSect = FindSctFrm();
         // The content of a FtnContainer in a (column) section only need to be calculated
-        // if the section streches already to the bottom edge of the Upper.
+        // if the section stretches already to the bottom edge of the Upper.
         if( pSect && !pSect->IsJoinLocked() && ( bEnd ? !pSect->IsEndnAtEnd() :
             !pSect->IsFtnAtEnd() ) && pSect->Growable() )
             pSect->InvalidateSize();
diff --git a/test/source/mtfxmldump.cxx b/test/source/mtfxmldump.cxx
index 6e12524..7bda52b 100644
--- a/test/source/mtfxmldump.cxx
+++ b/test/source/mtfxmldump.cxx
@@ -169,7 +169,7 @@ OString convertLineStyleToString(const sal_uInt16 nActionType)
         case META_POLYPOLYGON_ACTION:           return "polypolygon";
         case META_TEXT_ACTION:                  return "text";
         case META_TEXTARRAY_ACTION:             return "textarray";
-        case META_STRETCHTEXT_ACTION:           return "strechtext";
+        case META_STRETCHTEXT_ACTION:           return "stretchtext";
         case META_TEXTRECT_ACTION:              return "textrect";
         case META_TEXTLINE_ACTION:              return "textline";
         case META_BMP_ACTION:                   return "bmp";
diff --git a/toolkit/test/accessibility/ov/ObjectViewContainer.java b/toolkit/test/accessibility/ov/ObjectViewContainer.java
index 2a59427..c7e647d 100644
--- a/toolkit/test/accessibility/ov/ObjectViewContainer.java
+++ b/toolkit/test/accessibility/ov/ObjectViewContainer.java
@@ -129,7 +129,7 @@ public class ObjectViewContainer
     }
 
     /** Update the layout manager by setting the vertical weight of the
-        bottom entry to 1 and so make it strech to over the available
+        bottom entry to 1 and so make it stretch to over the available
         space.
 
     */
diff --git a/vcl/opengl/win/WinDeviceInfo.cxx b/vcl/opengl/win/WinDeviceInfo.cxx
index a3d4d67..852cfba 100644
--- a/vcl/opengl/win/WinDeviceInfo.cxx
+++ b/vcl/opengl/win/WinDeviceInfo.cxx
@@ -1079,7 +1079,7 @@ void WinOpenGLDeviceInfo::FillBlacklist()
     IMPLEMENT_INTEL_DRIVER_BLOCKLIST(wgl::DRIVER_OS_WINDOWS_XP, wgl::IntelGMAX3000, wgl::V(6,14,10,5218));
     IMPLEMENT_INTEL_DRIVER_BLOCKLIST(wgl::DRIVER_OS_WINDOWS_XP, wgl::IntelGMAX4500HD, wgl::V(6,14,10,4969));
 
-    // StrechRect seems to suffer from precision issues which leads to artifacting
+    // StretchRect seems to suffer from precision issues which leads to artifacting
     // during content drawing starting with at least version 6.14.10.5082
     // and going until 6.14.10.5218. See bug 919454 and bug 949275 for more info.
     APPEND_TO_DRIVER_BLOCKLIST_RANGE(wgl::DRIVER_OS_WINDOWS_XP,
diff --git a/vcl/source/filter/sgvtext.cxx b/vcl/source/filter/sgvtext.cxx
index 290ff14..b1373c6 100644
--- a/vcl/source/filter/sgvtext.cxx
+++ b/vcl/source/filter/sgvtext.cxx
@@ -820,7 +820,7 @@ void FormatLine(UCHAR* TBuf, sal_uInt16& Index, ObjTextType& Atr0, ObjTextType&
                 }
             }
 
-            if (j==0) {                        // only one word ?  -> strech !
+            if (j==0) {                        // only one word ?  -> stretch !
                 for (i=li+1;i<=re;i++) {       // from left to right
                   Line[i]=Line[i]+MulDiv(i-li,BoxRest,re-li+1-1);
                 }
@@ -843,7 +843,7 @@ void FormatLine(UCHAR* TBuf, sal_uInt16& Index, ObjTextType& Atr0, ObjTextType&
             li=1;
             while (li<=re && (cLine[li]==' ' || cLine[li]==TextEnd || cLine[li]==AbsatzEnd)) li++;
             BoxRest=AdjWdt-Line[re+1];
-            for (i=li+1;i<=re;i++) {         // strech from left to right
+            for (i=li+1;i<=re;i++) {         // stretch from left to right
                 Line[i]=Line[i]+MulDiv(i-li,BoxRest,re-li+1-1);
             }
             for (i=re+1;i<=nChars;i++) Line[i]=Line[i]+BoxRest; // adapt the rest
@@ -910,7 +910,7 @@ void TextType::Draw(OutputDevice& rOut)
     cLine.reset(new UCHAR[CharLineSize]);
 
     TextFit=(Flags & TextFitBits)!=0;
-    bool LineFit=((Flags & TextFitZBit)!=0);  // FitSize.x=0? or flags -> strech each line
+    bool LineFit=((Flags & TextFitZBit)!=0);  // FitSize.x=0? or flags -> stretch each line
     if (TextFit && FitSize.x==0) LineFit=true;
 
     if (RotationAngle==0) {


More information about the Libreoffice-commits mailing list